/**
 * @file ChildID.hh
 *
 * @brief  DIET ChildID implementation header
 *
 * @author  Sylvain DAHAN (Sylvain.Dahan@lifc.univ-fcomte.fr)
 *
 * @section Licence
 *
 * Copyright ENS Lyon, INRIA, UCBL, SysFera (2000)
 *
 * - Frederic.Desprez@ens-lyon.fr (Project Manager)
 * - Eddy.Caron@ens-lyon.fr (Technical Manager)
 * - Tech@sysfera.com (Maintainer and Technical Support)
 *
 * This software is a computer program whose purpose is to provide an
 * easy and transparent access to distributed and heterogeneous
 * platforms.
 *
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided
 * only with a limited warranty  and the software's author,  the holder
 * of the economic rights,  and the successive licensors  have only
 * limited liability.
 *
 * In this respect, the user's attention is drawn to the risks
 * associated with loading,  using,  modifying and/or developing or
 * reproducing the software by the user in light of its specific status
 * of free software, that may mean  that it is complicated to
 * manipulate, and  that  also therefore means  that it is reserved for
 * developers and experienced professionals having in-depth computer
 * knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions
 * enabling the security of their systems and/or data to be ensured and,
 * more generally, to use and operate it in the same conditions as
 * regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
 */


#ifndef _CHILD_ID_
#define _CHILD_ID_

#include <omniORB4/CORBA.h>



class ChildID {
public:

  /**
   * Creates a new default ChildID with the value of -1.
   *
   * @param n the initial value of the ChildID.
   */
  explicit
  ChildID(CORBA::Long n = -1): value(n) {
  }

  /**
   * Clones a ChildID.
   *
   * @param childID the ChildID to clone
   */
  ChildID(const ChildID &childID) {
    value = childID.value;
  }

  /**
   * The instance get the same value as \c aChildID.
   *
   * @param aChildID The ChildID where the value is taken.
   */
  inline ChildID &
  operator = (const ChildID &aChildID) {
    value = aChildID.value;
    return *this;
  }

  inline ChildID &
  operator = (const CORBA::Long & val) {
    value = val;
    return *this;
  }

  /**
   * Converts the ChildID to a \c CORBA::Long value.
   */
  inline operator
  CORBA::Long() const {
    return value;
  }

private:
  /**
   * the value of the ChildID
   */
  CORBA::Long value;
};

#endif  // _CHILD_ID_
