/**
 * @file MultiWfFOFT.hh
 *
 * @brief  Another multi-workflow scheduler based on Fairness On Finish Time algorithm
 *
 * @author  Abdelkader AMAR (Abdelkader.Amar@ens-lyon.fr)
 *          Benjamin Isnard (Benjamin.Isnard@ens-lyon.fr)
 *
 * @section Licence
 *
 * Copyright ENS Lyon, INRIA, UCBL, SysFera (2000)
 *
 * - Frederic.Desprez@ens-lyon.fr (Project Manager)
 * - Eddy.Caron@ens-lyon.fr (Technical Manager)
 * - Tech@sysfera.com (Maintainer and Technical Support)
 *
 * This software is a computer program whose purpose is to provide an
 * easy and transparent access to distributed and heterogeneous
 * platforms.
 *
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided
 * only with a limited warranty  and the software's author,  the holder
 * of the economic rights,  and the successive licensors  have only
 * limited liability.
 *
 * In this respect, the user's attention is drawn to the risks
 * associated with loading,  using,  modifying and/or developing or
 * reproducing the software by the user in light of its specific status
 * of free software, that may mean  that it is complicated to
 * manipulate, and  that  also therefore means  that it is reserved for
 * developers and experienced professionals having in-depth computer
 * knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions
 * enabling the security of their systems and/or data to be ensured and,
 * more generally, to use and operate it in the same conditions as
 * regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
 */


#ifndef _MULTIWFFOFT_HH_
#define _MULTIWFFOFT_HH_

#include <map>
#include <vector>

#include "MultiWfScheduler.hh"

namespace madag {
class MultiWfFOFT : public MultiWfScheduler {
public:
  explicit
  MultiWfFOFT(MaDag_impl *maDag);
  virtual ~MultiWfFOFT();

protected:
  /**
   * Updates scheduler when a node has been executed
   */
  virtual void
  handlerNodeDone(DagNode *node);

  /**
   * internal dag scheduling
   */
  virtual void
  intraDagSchedule(Dag *dag, MasterAgent_var MA)
  throw(MaDag::ServiceNotFound, MaDag::CommProblem);

  /**
   * set node priority before inserting into execution queue
   */
  virtual void
  setExecPriority(DagNode *node);

  /**
   * set node priority before inserting back in the ready queue
   */
  virtual void
  setWaitingPriority(DagNode *node);

  /**
   * updates the delay for a given node and change the current dag
   * slowdown value accordingly if the dag delay is impacted
   * @param node
   * @param delay delay in ms
   */
  virtual void
  updateNodeDelay(DagNode *node, double delay);

private:
  /**
   * Save the state of dags
   */
  std::map<Dag *, DagState> dagsState;

  /**
   * Mark the nodes which priority must be re-calculated
   */
  std::map<DagNode *, bool> nodesFlag;
};
}

#endif   /* not defined _MULTIWFFAIRNESS_SCHED_HH */
