/**
* @file DagScheduler.hh
* 
* @brief  Abstract interface for dag schedulers to handle execution events 
* 
* @author  Benjamin ISNARD (Benjamin.Isnard@ens-lyon.fr)
* 
* @section Licence
 *
 * Copyright ENS Lyon, INRIA, UCBL, SysFera (2000)
 *
 * - Frederic.Desprez@ens-lyon.fr (Project Manager)
 * - Eddy.Caron@ens-lyon.fr (Technical Manager)
 * - Tech@sysfera.com (Maintainer and Technical Support)
 *
 * This software is a computer program whose purpose is to provide an
 * easy and transparent access to distributed and heterogeneous
 * platforms.
 *
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided
 * only with a limited warranty  and the software's author,  the holder
 * of the economic rights,  and the successive licensors  have only
 * limited liability.
 *
 * In this respect, the user's attention is drawn to the risks
 * associated with loading,  using,  modifying and/or developing or
 * reproducing the software by the user in light of its specific status
 * of free software, that may mean  that it is complicated to
 * manipulate, and  that  also therefore means  that it is reserved for
 * developers and experienced professionals having in-depth computer
 * knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions
 * enabling the security of their systems and/or data to be ensured and,
 * more generally, to use and operate it in the same conditions as
 * regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
*/


#ifndef _DAG_SCHEDULER_HH_
#define _DAG_SCHEDULER_HH_

class Dag;
class DagNode;

class DagScheduler {
public:
  virtual ~DagScheduler() {
  }

  /**
   * Handle DAG DONE event
   * This event is triggered when all the nodes of the dag have been
   * completed without any error
   * @param dag the dag reference
   */
  virtual void
  handlerDagDone(Dag *dag) = 0;

  /**
   * Handle NODE READY event
   * This event is triggered when one dag node's dependencies (ie previous
   * nodes) are all completed. This is also triggered if the node has no
   * dependencies when created (input node).
   * @param node  the dag node reference
   */
  virtual void
  handlerNodeReady(DagNode *node) = 0;

  /**
   * Handle NODE DONE event
   * This event is triggered when one dag node has been completed
   * without any error
   * @param node  the dag node reference
   */
  virtual void
  handlerNodeDone(DagNode *node) = 0;

  /**
   * Get the current timestamp provided by the scheduler's clock
   * @return double value of the timestamp
   */
  virtual double
  getRelCurrTime() = 0;
};

#endif
